package bbs;

import java.util.Vector;

public class ObservableMessageList extends MessageList implements ObservableObject {
  private Vector observers = new Vector();
  
  /**
   * This method allows objects to register observers with our object
   *
   * @arg obs The observer that wants to receive messages from our object
   */
  public void addObserver(ObserverObject obs) { 
  	observers.addElement(obs); 
  }
  
  /**
   * This method allows objects to unregister observers
   *
   * @arg obs The observer that no longer wants to receive messages
   */
  public void removeObserver(ObserverObject obs) {
  	observers.removeElement(obs); 
  }

  /**
   * This method is called when a new message has been received.  It
   * notifies all observers that a message was received, and sends the
   * new message to each observer.
   *
   * @arg message The new message.
   */
  public void messageReceived(Message message) {
     for (int i = 0; i < observers.size(); i++) {
     	  // notify this observer of the new message
         ((MessageObserver)observers.elementAt(i)).messageReceived(message);
     }
  }
  
  /**
   * This method inserts a new message into the message list, and notifies
   * its observers (by calling messageRecieved()).
   *
   * @arg message The new message.
   *
   * @see messageReceived()
   */
  public void addMessage(Message message) {
  	super.addMessage(message);
  	messageReceived(message);
  }
}
