package bbs.client;

import bbs.*;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.net.Socket;

public class ClientMessageProxy extends ObservableMessageList implements Runnable {
  private BufferedReader input = null;
  private boolean running = true;
  
  /**
   * This constructor creates a client message proxy that connects to the
   * specified address and port and waits for messages.
   *
   * @arg address The network address of the server
   * @arg port The network port of the server
   */
  public ClientMessageProxy(String address, int port) throws IOException {
  	// create a socket connection to the server
	Socket socket = new Socket(address, port);
	
	// store the input stream so that we can read messages later
	this.input = new BufferedReader(new InputStreamReader(socket.getInputStream()));
  }

  /**
   * This method is used to stop the client message proxy from listening
   * for messages
   */
  public void close() {
  	running = false;
  }

  /**
   * This method is the main loop of this thread.  It simply continuously
   * reads messages until the client exits (indicated by the 'running' flag
   */
  public void run() {
  	while(running) {
  		try {
			String msgStr = input.readLine();
			Message msg = new Message(msgStr);
			addMessage(msg);
  		} catch (IOException e) {
  			e.printStackTrace();
  		}
  	}
  }  
}