package bbs.server;

import bbs.*;
import java.io.PrintWriter;
import java.io.OutputStream;
import java.io.IOException;
import java.net.Socket;

public class ServerMessageProxy implements MessageObserver {
  private PrintWriter output = null;
  private String address = null;
  private int port = 0;
  private OutputStream os = null;

  /**
   * This constructor creates a server message proxy to handle the
   * connection associated with the specified socket.
   *
   * @arg socket The socket for the connection we wish to handle.
   */
  public ServerMessageProxy(Socket socket) {
  	try {
  		os = socket.getOutputStream();
  	} catch (IOException e) {
  		e.printStackTrace();
  	}
	this.output = new PrintWriter(os);

	this.address = socket.getInetAddress().toString();
	this.port = socket.getPort();
  }

  /**
   * This method sends all messages, that were previously sent, to the
   * server message proxy, and eventually to the client.  This is used
   * to send the historical messages to newly connected clients.
   *
   * @arg messageList The message list.
   */
  public void sendCachedMessages(MessageList messageList) {
  	Message[] msgs = messageList.getMessages();
  	for (int i = 0; i < msgs.length; i++) {
  		messageReceived(msgs[i]);
  	}
  }

  /**
   * This method is called when a message is added to the message store.
   * The method sends the message to the client associated with this
   * server message proxy.
   *
   * @arg message The new message that needs to be sent to the client.
   */
  public void messageReceived(Message message) {
  	// send the message to the client proxy
	String str = message.toString()+"\n";
	try {
  		os.write(str.getBytes());
  	} catch (IOException e) {
  		e.printStackTrace();
  	}
  }
}